#include <ESP8266WebServer.h>
#include "secrets.h"

#include <Wire.h>
#include <Adafruit_Sensor.h>
#include <Adafruit_BME280.h>

#define SEALEVELPRESSURE_HPA (1013.25)
Adafruit_BME280 bme;
float temperature, humidity, pressure, altitude;

ESP8266WebServer server(80);


void setup() {
  setup_wifi();
  bme.begin(0x76);
  server.on("/", handle_OnConnect);
  server.onNotFound(handle_NotFound);
  server.begin();
}
void loop() {
  server.handleClient();
}

void setup_wifi() {
  Serial.begin(115200);
  WiFi.mode(WIFI_STA);
  WiFi.begin(WIFI_SSID, WIFI_PASS);
  Serial.print("Connecting to ");
  Serial.print(WIFI_SSID);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println();
  Serial.print("Connected! IP address: ");
  Serial.println(WiFi.localIP());
}


void handle_OnConnect() {
  temperature = bme.readTemperature();
  humidity = bme.readHumidity();
  pressure = (bme.readPressure() + 1440) / 100.0F;
  altitude = bme.readAltitude(SEALEVELPRESSURE_HPA);
  server.send(200, "text/html", SendHTML(temperature, humidity, pressure, altitude));
}

void handle_NotFound() {
  server.send(404, "text/plain", "Not found");
}

String SendHTML(float temperature, float humidity, float pressure, float altitude) {
  String ptr = F("<!DOCTYPE html> <html>"
                 "<head><meta name=\"viewport\" content=\"width=device-width, initial-scale=1.0\">"
                 "<title>ESP8266 Weather Station</title>"
                 "<link rel=\"icon\" href=\"data:,\">"
                 "<style>html { font-family: Helvetica; display: inline-block;"
                 "margin: 0px auto; text-align: center;}"
                 "body{margin-top: 50px;} h1 {color: #730841;margin: 50px auto 30px;}"
                 "p {font-size: 24px;color: #444444;margin-bottom: 10px;}"
                 "</style>"
                 "<script>\n"
                 "setInterval(loadDoc,5000);\n"
                 "function loadDoc() {\n"
                 "var xhttp = new XMLHttpRequest();\n"
                 "xhttp.onreadystatechange = function() {\n"
                 "if (this.readyState == 4 && this.status == 200) {\n"
                 "document.getElementById('webpage').innerHTML =this.responseText}\n"
                 "};\n"
                 "xhttp.open(\"GET\", \"/\", true);\n"
                 "xhttp.send();\n"
                 "}\n"
                 "</script>\n"
                 "</head ><body>"
                 "<div id = \"webpage\">"
                 "<h1>ESP8266 Weather Station</h1>");
  ptr += "<p>Temperature: " + String(temperature, 1) + " &deg;C</p>";
  ptr += "<p>Humidity: " + String(humidity, 0) + " %</p>";
  ptr += "<p>Pressure: " + String(pressure, 1) + " hPa</p>";
  ptr += "<p>Altitude: " + String(altitude, 0) + " m</p>";
  ptr += "</div></body></html>\n";
  return ptr;
}
